@@ -1,15 +1,4 @@
-setOldClass("causalWeights")
-
-
-ESS.default <- function(x) {
-  return(1/sum(x^2))
-}
-
-ESS.causalWeights <- function(x) {
-  return(c("Control" = ESS(x$w0), "Treated" = ESS(x$w1)))
-}
-
-
+# setOldClass("causalWeights")
 
 #' Effective Sample Size
 #'
@@ -34,12 +23,22 @@ ESS.causalWeights <- function(x) {
 #' @examples
 #' x <- rep(1/100,100)
 #' ESS(x)
-setGeneric("ESS", function(x) UseMethod("ESS"))
+setGeneric("ESS", def = function(x) standardGeneric("ESS"))
+
 
 #' @describeIn ESS default ESS method for numeric vectors
 #' @method ESS default
-setMethod("ESS", signature(x = "numeric"), ESS.default)
+setMethod("ESS", signature(x = "numeric"), 
+    function(x) {
+      return(1/sum(x^2))
+    }          
+)
 
 #' @describeIn ESS ESS method for objects of class [causalWeights][causalOT::causalWeights-class]
 #' @method ESS causalWeights
-setMethod("ESS", signature(x = "causalWeights"), ESS.causalWeights)
\ No newline at end of file
+#' @include weightsClass.R
+setMethod("ESS", signature = signature(x = "causalWeights"),
+function(x) {
+  return(c("Control" = ESS(x@w0), "Treated" = ESS(x@w1)))
+}
+)
